# sessel.py

from grafikfenster import *
from math import radians

### ---------------------------------------------------
class Sessel():
    """Klasse Sessel
    ermoeglicht das Zeichnen und Bearbeiten eines
    Sessel-Symbols fuer den Raumplaner"""

    def __init__(self, sichtbar=False):
        """einfacher Konstruktor"""
        self.x=200
        self.y=200
        self.b=60
        self.t=60
        self.w=0
        self.f='red'
        self.s=sichtbar
        if sichtbar: self.Zeige()
        
    def GibFigur(self):
        """definiert und transformiert die zu zeichnende Figur"""
        gc = Zeichenflaeche.GibZeichenflaeche().GibGC()
        path = gc.CreatePath()
        
        path.AddRectangle(0, 0, self.b, self.t)
        # linke Sessellehne 0,0, self.b/6,self.t
        path.AddRectangle(0, 0, self.b/6, self.t)
        # rechte Sessellehne 
        path.AddRectangle(5*self.b/6, 0, self.b/6, self.t)
        # Ruecklehne self.b/6,0, 4*self.b/6, self.t/6
        path.AddRectangle(self.b/6,0, 4*self.b/6, self.t/6)
        # Sitzflaeche durch Umriss
        
        gc.PushState()
        gc.Translate(self.x+self.b/2, self.y+self.t/2)
        gc.Rotate(radians(self.w))
        gc.Translate(-self.b/2, -self.t/2)
        transformation = gc.GetTransform()
        gc.PopState()
        path.Transform(transformation)
        return path

    def GibFarbe(self):
        """Get-Methode fuer die Farbe"""
        return self.f
    
    def GibSichtbar(self):
        """Get-Methode fuer die Sichtbarkeit"""
        return self.s

    def BewegeHorizontal(self, weite):
        """Veraendernde Methode fuer die x-Position"""
        self.Verberge()
        self.x += weite
        self.Zeige()
    
    def BewegeVertikal(self, weite):
        """Veraendernde Methode fuer die y-Position"""
        self.Verberge()
        self.y += weite
        self.Zeige()
    
    def Drehe(self, winkel):
        """Veraendernde Methode fuer die Orientierung [Winkel]"""
        self.Verberge()
        self.w += winkel
        self.Zeige()

    def Verberge(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert False"""
        self.s = False
        Zeichenflaeche.GibZeichenflaeche().Entferne(self)

    def Zeige(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert True"""
        self.s = True
        Zeichenflaeche.GibZeichenflaeche().Zeichne(self)

### ---------------------------------------------------
class SesselApp(wx.App):
    """Test-Anwendung speziell fuer Sessel"""
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.fenster.ZeigeShellFrame()
        #self.fenster.ZeigeFillingFrame()
        self.TestAnwendung()
        return True

    def TestAnwendung(self):
        """Allein fuer die Testanwendung:"""
        global sessel
        sessel=Sessel(True)
        
### ---------------------------------------------------
if __name__ == '__main__':
    app = SesselApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
